@@ -1,4 +1,4 @@
-# 互动社区
+# 互动社区问答
 from .base import base
 
 
@@ -10,6 +10,18 @@ class bbs(base):
         api_name = "bbs/getTagList"
         return self.request(api_name)
 
+    def getQuestList(self):
+        api_name = "bbs/getQuestList"
+        return self.request(api_name)
+
+    def getQuestuestByNonAnswer(self):
+        api_name = "bbs/getQuestList"
+        return self.request(api_name)
+
+    def answerQuestion(self):
+        api_name = "bbs/getQuestList"
+        return self.request(api_name)
+
     def list(self):
         api_name = "bbs/getActivityList"
         return self.request(api_name)
