@@ -1,3 +1,9 @@
+'''
+@author: renqiukai
+@Date: 2020-05-29 10:30:41
+@Description: 
+@LastEditTime: 2020-06-10 18:33:01
+'''
 import requests
 from .base import base
 
@@ -11,9 +17,9 @@ class cjdgUser(base):
         api_name = "user/create"
         return self.request(api_name, data)
 
-    def createBatch(self, **data):
-        api_name = "user/batchcreate"
-        return self.request(api_name, **data)
+    def createBatch(self, data):
+        data["api_name"] = "user/batchcreate"
+        return self.request(**data)
 
     def list(self, data):
         api_name = "user/query"
@@ -38,7 +44,7 @@ class cjdgUser(base):
         api_name = "user/modifi"
         return self.request(api_name, data)
 
-    def updateBatch(self, **data):
+    def updateBatch(self, data):
         api_name = "user/batchmodifi"
         return self.request(api_name, **data)
 
@@ -48,4 +54,4 @@ class cjdgUser(base):
 
     def enabled(self, data):
         api_name = "user/enabled"
-        return self.request(api_name, data)
\ No newline at end of file
+        return self.request(api_name, data)
